# Alnitak Changelog

## 0.1.1

* Made the logging code more robust (perhaps overkill...).
* Added tests to check the logging code works as expected.
* Modified the locking code to use fcntl.lockf.
* Added and/or fixed doctrings.
